@@ -37,7 +37,8 @@ class GoEnvironment(BaseEnvironment):
                 token = data.get('environments', {}).get(self.name, {}).get(
                     'admin-secret')
                 if token is None:
-                    raise EnvError("Environment config not found")
+                    raise EnvError({
+                        'Error': "Environment config not found %s" % self.name})
         with open(jenv) as fh:
             data = yaml_load(fh.read())
             token = data.get('bootstrap-config', {}).get(
